Struct amazon_sp_finances::models::removal_shipment_item_adjustment::RemovalShipmentItemAdjustment
source · [−]pub struct RemovalShipmentItemAdjustment {
pub removal_shipment_item_id: Option<String>,
pub tax_collection_model: Option<String>,
pub fulfillment_network_sku: Option<String>,
pub adjusted_quantity: Option<i32>,
pub revenue_adjustment: Option<Box<Currency>>,
pub tax_amount_adjustment: Option<Box<Currency>>,
pub tax_withheld_adjustment: Option<Box<Currency>>,
}Expand description
RemovalShipmentItemAdjustment : Item-level information for a removal shipment item adjustment.
Fields
removal_shipment_item_id: Option<String>An identifier for an item in a removal shipment.
tax_collection_model: Option<String>The tax collection model applied to the item. Possible values: * MarketplaceFacilitator - Tax is withheld and remitted to the taxing authority by Amazon on behalf of the seller. * Standard - Tax is paid to the seller and not remitted to the taxing authority by Amazon.
fulfillment_network_sku: Option<String>The Amazon fulfillment network SKU for the item.
adjusted_quantity: Option<i32>Adjusted quantity of removal shipmentItemAdjustment items.
revenue_adjustment: Option<Box<Currency>>tax_amount_adjustment: Option<Box<Currency>>tax_withheld_adjustment: Option<Box<Currency>>Implementations
sourceimpl RemovalShipmentItemAdjustment
impl RemovalShipmentItemAdjustment
sourcepub fn new() -> RemovalShipmentItemAdjustment
pub fn new() -> RemovalShipmentItemAdjustment
Item-level information for a removal shipment item adjustment.